package se.chalmers.tdv.queue;

import java.util.ArrayList;

import se.chalmers.tdv.minimize.Tuple;
import se.chalmers.tdv.testing.Interpreter;

public class QueueInterpret implements Interpreter<QueueAction, Tuple<Queue,ArrayList<Integer>>> {

	private int maxSize;
	
	public QueueInterpret(int maxSize) {
		this.maxSize = maxSize;
	}
	
	@Override
	public Tuple<Queue, ArrayList<Integer>> interpret(QueueAction[] actions) {
		
		Queue queue = new Queue(maxSize);
		ArrayList<Integer> out = new ArrayList<>();
		for(QueueAction action : actions){
			switch (action.type) {
			case ISEMPTY:
				out.add(queue.isEmpty() ? 1 : 0);
				break;
			case FRONT:
				out.add(queue.front());
				break;
			case OUTPUT:
				out.add(action.value);
				break;
			case REMOVE:
				queue.remove();
				break;
			case ADD:
				queue.add(action.value);
				break;
			}
		}
		return new Tuple<Queue, ArrayList<Integer>>(queue, out);
		
	}

	@Override
	public int getShrinkLevel() {
		return maxSize;
	}

	@Override
	public void setShrinkLevel(int level) {
		this.maxSize = level;
		
	}

	@Override
	public String shrinkLevelName() {
		return "Initial queue size";
	}

	@Override
	public String getHeader(String name) {
		return "Queue " + name + " = new Queue(" + maxSize + ");";
		
	}
	

}
